@@ -10,6 +10,8 @@
 // import required webpack plugins
 const TerserPlugin = require('terser-webpack-plugin');
 const OptimizeCSSAssetsPlugin = require('optimize-css-assets-webpack-plugin');
+const SentryCliPlugin = require('@sentry/webpack-plugin');
+const shelljs = require('shelljs');
 
 // import webpack development configuration
 var webpackProdConfig = require('./webpack.config.development');
@@ -37,6 +39,18 @@ webpackProdConfig.optimization.minimizer = [
   })
 ];
 
+// upload js source maps to Sentry for better debugging
+webpackProdConfig.plugins.push(new SentryCliPlugin({
+  include: 'static/js',
+  urlPrefix: '~/static/js',
+  org: 'swh',
+  project: 'swh-webapp',
+  url: 'https://sentry.softwareheritage.org/',
+  dryRun: process.env.SENTRY_AUTH_TOKEN === undefined,
+  release: shelljs.exec('git describe --abbrev=0', {silent: true}).stdout.slice(1, -1),
+  sourceMapReference: false
+}));
+
 // prevent modules concatenation for generating weblabels
 webpackProdConfig.optimization.concatenateModules = false;
 
