@@ -1,10 +1,13 @@
-# Copyright (C) 2015-2020  The Software Heritage developers
+# Copyright (C) 2015-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
 from distutils.util import strtobool
 from functools import partial
+from typing import Dict
+
+from rest_framework.request import Request
 
 from swh.search.exc import SearchQuerySyntaxError
 from swh.web.api.apidoc import api_doc, format_docstring
@@ -15,10 +18,10 @@ from swh.web.api.utils import (
     enrich_origin_visit,
 )
 from swh.web.api.views.utils import api_lookup
-from swh.web.common import archive
-from swh.web.common.exc import BadInputExc
-from swh.web.common.origin_visits import get_origin_visits
-from swh.web.common.utils import origin_visit_types, reverse
+from swh.web.utils import archive, origin_visit_types, reverse
+from swh.web.utils.exc import BadInputExc
+from swh.web.utils.origin_visits import get_origin_visits
+from swh.web.utils.typing import OriginInfo
 
 DOC_RETURN_ORIGIN = """
         :>json string origin_visits_url: link to in order to get information
@@ -41,6 +44,10 @@ DOC_RETURN_ORIGIN_VISIT = """
         :>json string status: status of the visit (either **full**,
             **partial** or **ongoing**)
         :>json number visit: the unique identifier of the visit
+        :>json string metadata_authorities_url: link to
+            :http:get:`/api/1/raw-extrinsic-metadata/swhid/(target)/authorities/`
+            to get the list of metadata authorities providing extrinsic metadata
+            on this origin (and, indirectly, to the origin's extrinsic metadata itself)
 """
 
 DOC_RETURN_ORIGIN_VISIT_ARRAY = DOC_RETURN_ORIGIN_VISIT.replace(":>json", ":>jsonarr")
@@ -54,9 +61,9 @@ DOC_RETURN_ORIGIN_VISIT_ARRAY += """
 
 
 @api_route(r"/origins/", "api-1-origins")
-@api_doc("/origins/", noargs=True)
+@api_doc("/origins/", category="Archive", noargs=True)
 @format_docstring(return_origin_array=DOC_RETURN_ORIGIN_ARRAY)
-def api_origins(request):
+def api_origins(request: Request):
     """
     .. http:get:: /api/1/origins/
 
@@ -98,20 +105,20 @@ def api_origins(request):
     origins = [enrich_origin(o, request=request) for o in page_result.results]
     next_page_token = page_result.next_page_token
 
-    response = {"results": origins, "headers": {}}
+    headers: Dict[str, str] = {}
     if next_page_token is not None:
-        response["headers"]["link-next"] = reverse(
+        headers["link-next"] = reverse(
             "api-1-origins",
-            query_params={"page_token": next_page_token, "origin_count": limit},
+            query_params={"page_token": next_page_token, "origin_count": str(limit)},
             request=request,
         )
-    return response
+    return {"results": origins, "headers": headers}
 
 
 @api_route(r"/origin/(?P<origin_url>.+)/get/", "api-1-origin")
-@api_doc("/origin/")
+@api_doc("/origin/", category="Archive")
 @format_docstring(return_origin=DOC_RETURN_ORIGIN)
-def api_origin(request, origin_url):
+def api_origin(request: Request, origin_url: str):
     """
     .. http:get:: /api/1/origin/(origin_url)/get/
 
@@ -140,13 +147,14 @@ def api_origin(request, origin_url):
     return api_lookup(
         archive.lookup_origin,
         ori_dict,
+        lookup_similar_urls=False,
         notfound_msg=error_msg,
         enrich_fn=enrich_origin,
         request=request,
     )
 
 
-def _visit_types():
+def _visit_types() -> str:
     docstring = ""
     # available visit types are queried using swh-search so we do it in a try
     # block in case of failure (for instance in docker environment when
@@ -165,11 +173,11 @@ def _visit_types():
     "api-1-origin-search",
     throttle_scope="swh_api_origin_search",
 )
-@api_doc("/origin/search/")
+@api_doc("/origin/search/", category="Archive")
 @format_docstring(
     return_origin_array=DOC_RETURN_ORIGIN_ARRAY, visit_types=_visit_types()
 )
-def api_origin_search(request, url_pattern):
+def api_origin_search(request: Request, url_pattern: str):
     """
     .. http:get:: /api/1/origin/search/(url_pattern)/
 
@@ -247,9 +255,9 @@ def api_origin_search(request, url_pattern):
 
 
 @api_route(r"/origin/metadata-search/", "api-1-origin-metadata-search")
-@api_doc("/origin/metadata-search/", noargs=True)
+@api_doc("/origin/metadata-search/", category="Metadata", noargs=True)
 @format_docstring(return_origin_array=DOC_RETURN_ORIGIN_ARRAY)
-def api_origin_metadata_search(request):
+def api_origin_metadata_search(request: Request):
     """
     .. http:get:: /api/1/origin/metadata-search/
 
@@ -290,10 +298,10 @@ def api_origin_metadata_search(request):
     }
 
 
-@api_route(r"/origin/(?P<origin_url>.*)/visits/", "api-1-origin-visits")
-@api_doc("/origin/visits/")
+@api_route(r"/origin/(?P<origin_url>.+)/visits/", "api-1-origin-visits")
+@api_doc("/origin/visits/", category="Archive")
 @format_docstring(return_origin_visit_array=DOC_RETURN_ORIGIN_VISIT_ARRAY)
-def api_origin_visits(request, origin_url):
+def api_origin_visits(request: Request, origin_url: str):
     """
     .. http:get:: /api/1/origin/(origin_url)/visits/
 
@@ -323,16 +331,15 @@ def api_origin_visits(request, origin_url):
 
     """
     result = {}
-    origin_query = {"url": origin_url}
+    origin_query = OriginInfo(url=origin_url)
     notfound_msg = "No origin {} found".format(origin_url)
     url_args_next = {"origin_url": origin_url}
     per_page = int(request.query_params.get("per_page", "10"))
-    last_visit = request.query_params.get("last_visit")
-    if last_visit:
-        last_visit = int(last_visit)
+    last_visit_str = request.query_params.get("last_visit")
+    last_visit = int(last_visit_str) if last_visit_str else None
 
     def _lookup_origin_visits(origin_query, last_visit=last_visit, per_page=per_page):
-        all_visits = get_origin_visits(origin_query)
+        all_visits = get_origin_visits(origin_query, lookup_similar_urls=False)
         all_visits.reverse()
         visits = []
         if not last_visit:
@@ -380,13 +387,13 @@ def api_origin_visits(request, origin_url):
 
 
 @api_route(
-    r"/origin/(?P<origin_url>.*)/visit/latest/",
+    r"/origin/(?P<origin_url>.+)/visit/latest/",
     "api-1-origin-visit-latest",
     throttle_scope="swh_api_origin_visit_latest",
 )
-@api_doc("/origin/visit/latest/")
+@api_doc("/origin/visit/latest/", category="Archive")
 @format_docstring(return_origin_visit=DOC_RETURN_ORIGIN_VISIT)
-def api_origin_visit_latest(request, origin_url=None):
+def api_origin_visit_latest(request: Request, origin_url: str):
     """
     .. http:get:: /api/1/origin/(origin_url)/visit/latest/
 
@@ -410,11 +417,13 @@ def api_origin_visit_latest(request, origin_url=None):
 
             :swh_web_api:`origin/https://github.com/hylang/hy/visit/latest/`
     """
+
     require_snapshot = request.query_params.get("require_snapshot", "false")
     return api_lookup(
         archive.lookup_origin_visit_latest,
         origin_url,
         bool(strtobool(require_snapshot)),
+        lookup_similar_urls=False,
         notfound_msg=("No visit for origin {} found".format(origin_url)),
         enrich_fn=partial(
             enrich_origin_visit, with_origin_link=True, with_origin_visit_link=False
@@ -424,11 +433,11 @@ def api_origin_visit_latest(request, origin_url=None):
 
 
 @api_route(
-    r"/origin/(?P<origin_url>.*)/visit/(?P<visit_id>[0-9]+)/", "api-1-origin-visit"
+    r"/origin/(?P<origin_url>.+)/visit/(?P<visit_id>[0-9]+)/", "api-1-origin-visit"
 )
-@api_doc("/origin/visit/")
+@api_doc("/origin/visit/", category="Archive")
 @format_docstring(return_origin_visit=DOC_RETURN_ORIGIN_VISIT)
-def api_origin_visit(request, visit_id, origin_url):
+def api_origin_visit(request: Request, visit_id: str, origin_url: str):
     """
     .. http:get:: /api/1/origin/(origin_url)/visit/(visit_id)/
 
@@ -451,10 +460,12 @@ def api_origin_visit(request, visit_id, origin_url):
 
             :swh_web_api:`origin/https://github.com/hylang/hy/visit/1/`
     """
+
     return api_lookup(
         archive.lookup_origin_visit,
         origin_url,
         int(visit_id),
+        lookup_similar_urls=False,
         notfound_msg=("No visit {} for origin {} found".format(visit_id, origin_url)),
         enrich_fn=partial(
             enrich_origin_visit, with_origin_link=True, with_origin_visit_link=False
@@ -466,9 +477,9 @@ def api_origin_visit(request, visit_id, origin_url):
 @api_route(
     r"/origin/(?P<origin_url>.+)/intrinsic-metadata/", "api-origin-intrinsic-metadata"
 )
-@api_doc("/origin/intrinsic-metadata/")
+@api_doc("/origin/intrinsic-metadata/", category="Metadata")
 @format_docstring()
-def api_origin_intrinsic_metadata(request, origin_url):
+def api_origin_intrinsic_metadata(request: Request, origin_url: str):
     """
     .. http:get:: /api/1/origin/(origin_url)/intrinsic-metadata
 
