@@ -1,33 +1,32 @@
-# Copyright (C) 2015-2019  The Software Heritage developers
+# Copyright (C) 2015-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
 from types import GeneratorType
-from typing import Any, Callable, Dict, Mapping, Optional
-
-from typing_extensions import Protocol
+from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 
 from django.http import HttpRequest
 from rest_framework.decorators import api_view
+from rest_framework.request import Request
 from rest_framework.response import Response
 
 from swh.web.api.apiurls import APIUrls, api_route
-from swh.web.common.exc import NotFoundExc
+from swh.web.utils.exc import NotFoundExc
 
+EnrichFunction = Callable[[Dict[str, str], Optional[HttpRequest]], Dict[str, str]]
 
-class EnrichFunction(Protocol):
-    def __call__(
-        self, input: Mapping[str, str], request: Optional[HttpRequest]
-    ) -> Dict[str, str]:
-        ...
+EnrichFunctionSearchResult = Callable[
+    [Tuple[List[Dict[str, Any]], Optional[str]], Optional[HttpRequest]],
+    Tuple[List[Dict[str, Any]], Optional[str]],
+]
 
 
 def api_lookup(
     lookup_fn: Callable[..., Any],
     *args: Any,
     notfound_msg: Optional[str] = "Object not found",
-    enrich_fn: Optional[EnrichFunction] = None,
+    enrich_fn: Optional[Union[EnrichFunction, EnrichFunctionSearchResult]] = None,
     request: Optional[HttpRequest] = None,
     **kwargs: Any,
 ):
@@ -69,24 +68,33 @@ def api_lookup(
     if res is None:
         raise NotFoundExc(notfound_msg)
     if isinstance(res, (list, GeneratorType)) or type(res) == map:
-        return [enrich_fn(x, request=request) for x in res]
-    return enrich_fn(res, request=request)
+        return [enrich_fn(x, request) for x in res]
+    return enrich_fn(res, request)
 
 
 @api_view(["GET", "HEAD"])
-def api_home(request):
-    return Response({}, template_name="api/api.html")
+def api_home(request: Request):
+    return Response({}, template_name="api.html")
 
 
-APIUrls.add_url_pattern(r"^$", api_home, view_name="api-1-homepage")
+APIUrls.add_url_pattern(r"^api/$", api_home, view_name="api-1-homepage")
 
 
 @api_route(r"/", "api-1-endpoints")
 def api_endpoints(request):
     """Display the list of opened api endpoints."""
-    routes = APIUrls.get_app_endpoints().copy()
-    for route, doc in routes.items():
+    routes_by_category = {}
+    for route, doc in APIUrls.get_app_endpoints().items():
         doc["doc_intro"] = doc["docstring"].split("\n\n")[0]
-    # Return a list of routes with consistent ordering
-    env = {"doc_routes": sorted(routes.items())}
-    return Response(env, template_name="api/endpoints.html")
+        routes_by_category.setdefault(doc["category"], []).append(doc)
+
+    for routes in routes_by_category.values():
+        routes.sort(key=lambda route: route["route"])
+
+    # sort routes by alphabetical category name, with 'miscellaneous' at the end
+    misc_routes = routes_by_category.pop("Miscellaneous")
+    sorted_routes = sorted(routes_by_category.items())
+    sorted_routes.append(("Miscellaneous", misc_routes))
+
+    env = {"doc_routes": sorted_routes}
+    return Response(env, template_name="api-endpoints.html")
