@@ -14,10 +14,6 @@ from cryptography.hazmat.primitives.kdf.pbkdf2 import PBKDF2HMAC
 from django.contrib.auth.decorators import user_passes_test
 from django.http.request import HttpRequest
 
-from swh.web.common.exc import ForbiddenExc
-
-OIDC_SWH_WEB_CLIENT_ID = "swh-web"
-
 SWH_AMBASSADOR_PERMISSION = "swh.ambassador"
 API_SAVE_ORIGIN_PERMISSION = "swh.web.api.save_origin"
 ADMIN_LIST_DEPOSIT_PERMISSION = "swh.web.admin.list_deposits"
@@ -111,6 +107,18 @@ def any_permission_required(*perms):
     def check_perms(user):
         if any(user.has_perm(perm) for perm in perms):
             return True
+        from swh.web.utils.exc import ForbiddenExc
+
         raise ForbiddenExc
 
     return user_passes_test(check_perms)
+
+
+def is_add_forge_now_moderator(user) -> bool:
+    """Is a user considered an add-forge-now moderator?
+
+    Returns
+        True if a user is staff or has add forge now moderator permission
+
+    """
+    return user.is_staff or user.has_perm(ADD_FORGE_MODERATOR_PERMISSION)
