@@ -17,38 +17,41 @@ from swh.search.interface import PagedResult
 from swh.storage.exc import StorageAPIError, StorageDBError
 from swh.storage.utils import now
 from swh.web.api.utils import enrich_origin, enrich_origin_visit
-from swh.web.common.exc import BadInputExc
-from swh.web.common.origin_visits import get_origin_visits
-from swh.web.common.utils import reverse
 from swh.web.tests.api.views.utils import scroll_results
 from swh.web.tests.data import (
     INDEXER_TOOL,
+    ORIGIN_MASTER_DIRECTORY,
     ORIGIN_MASTER_REVISION,
     ORIGIN_METADATA_KEY,
     ORIGIN_METADATA_VALUE,
 )
+from swh.web.tests.helpers import check_api_get_responses
 from swh.web.tests.strategies import new_origin, new_snapshots, visit_dates
-from swh.web.tests.utils import check_api_get_responses
+from swh.web.utils import reverse
+from swh.web.utils.exc import BadInputExc
+from swh.web.utils.origin_visits import get_origin_visits
 
 
-def test_api_lookup_origin_visits_raise_error(api_client, mocker):
+def test_api_lookup_origin_visits_raise_error(api_client, origin, mocker):
     mock_get_origin_visits = mocker.patch("swh.web.api.views.origin.get_origin_visits")
     err_msg = "voluntary error to check the bad request middleware."
 
     mock_get_origin_visits.side_effect = BadInputExc(err_msg)
 
-    url = reverse("api-1-origin-visits", url_args={"origin_url": "http://foo"})
+    url = reverse("api-1-origin-visits", url_args={"origin_url": origin["url"]})
     rv = check_api_get_responses(api_client, url, status_code=400)
     assert rv.data == {"exception": "BadInputExc", "reason": err_msg}
 
 
-def test_api_lookup_origin_visits_raise_swh_storage_error_db(api_client, mocker):
+def test_api_lookup_origin_visits_raise_swh_storage_error_db(
+    api_client, origin, mocker
+):
     mock_get_origin_visits = mocker.patch("swh.web.api.views.origin.get_origin_visits")
     err_msg = "Storage exploded! Will be back online shortly!"
 
     mock_get_origin_visits.side_effect = StorageDBError(err_msg)
 
-    url = reverse("api-1-origin-visits", url_args={"origin_url": "http://foo"})
+    url = reverse("api-1-origin-visits", url_args={"origin_url": origin["url"]})
     rv = check_api_get_responses(api_client, url, status_code=503)
     assert rv.data == {
         "exception": "StorageDBError",
@@ -56,13 +59,15 @@ def test_api_lookup_origin_visits_raise_swh_storage_error_db(api_client, mocker)
     }
 
 
-def test_api_lookup_origin_visits_raise_swh_storage_error_api(api_client, mocker):
+def test_api_lookup_origin_visits_raise_swh_storage_error_api(
+    api_client, origin, mocker
+):
     mock_get_origin_visits = mocker.patch("swh.web.api.views.origin.get_origin_visits")
     err_msg = "Storage API dropped dead! Will resurrect asap!"
 
     mock_get_origin_visits.side_effect = StorageAPIError(err_msg)
 
-    url = reverse("api-1-origin-visits", url_args={"origin_url": "http://foo"})
+    url = reverse("api-1-origin-visits", url_args={"origin_url": origin["url"]})
     rv = check_api_get_responses(api_client, url, status_code=503)
     assert rv.data == {
         "exception": "StorageAPIError",
@@ -447,7 +452,7 @@ def test_api_origin_not_found(api_client, new_origin):
 def test_api_origin_search(api_client, mocker, backend):
     if backend != "swh-search":
         # equivalent to not configuring search in the config
-        mocker.patch("swh.web.common.archive.search", None)
+        mocker.patch("swh.web.utils.archive.search", None)
 
     expected_origins = {
         "https://github.com/wcoder/highlightjs-line-numbers.js",
@@ -499,7 +504,7 @@ def test_api_origin_search(api_client, mocker, backend):
 def test_api_origin_search_words(api_client, mocker, backend):
     if backend != "swh-search":
         # equivalent to not configuring search in the config
-        mocker.patch("swh.web.common.archive.search", None)
+        mocker.patch("swh.web.utils.archive.search", None)
 
     expected_origins = {
         "https://github.com/wcoder/highlightjs-line-numbers.js",
@@ -549,7 +554,7 @@ def test_api_origin_search_words(api_client, mocker, backend):
 def test_api_origin_search_visit_type(api_client, mocker, backend):
     if backend != "swh-search":
         # equivalent to not configuring search in the config
-        mocker.patch("swh.web.common.archive.search", None)
+        mocker.patch("swh.web.utils.archive.search", None)
 
     expected_origins = {
         "https://github.com/wcoder/highlightjs-line-numbers.js",
@@ -585,7 +590,7 @@ def test_api_origin_search_use_ql(api_client, mocker):
 
     ORIGINS = [{"url": origin} for origin in expected_origins]
 
-    mock_archive_search = mocker.patch("swh.web.common.archive.search")
+    mock_archive_search = mocker.patch("swh.web.utils.archive.search")
     mock_archive_search.origin_search.return_value = PagedResult(
         results=ORIGINS,
         next_page_token=None,
@@ -607,7 +612,7 @@ def test_api_origin_search_use_ql(api_client, mocker):
 
 
 def test_api_origin_search_ql_syntax_error(api_client, mocker):
-    mock_archive_search = mocker.patch("swh.web.common.archive.search")
+    mock_archive_search = mocker.patch("swh.web.utils.archive.search")
     mock_archive_search.origin_search.side_effect = SearchQuerySyntaxError(
         "Invalid syntax"
     )
@@ -636,7 +641,7 @@ def test_api_origin_search_scroll(api_client, archive_data, mocker, limit, backe
 
     if backend != "swh-search":
         # equivalent to not configuring search in the config
-        mocker.patch("swh.web.common.archive.search", None)
+        mocker.patch("swh.web.utils.archive.search", None)
 
     expected_origins = {
         "https://github.com/wcoder/highlightjs-line-numbers.js",
@@ -662,7 +667,7 @@ def test_api_origin_search_limit(api_client, archive_data, tests_data, mocker, b
         )
     else:
         # equivalent to not configuring search in the config
-        mocker.patch("swh.web.common.archive.search", None)
+        mocker.patch("swh.web.utils.archive.search", None)
 
         archive_data.origin_add(
             [Origin(url="http://foobar/{}".format(i)) for i in range(2000)]
@@ -680,7 +685,7 @@ def test_api_origin_search_limit(api_client, archive_data, tests_data, mocker, b
 @pytest.mark.parametrize("backend", ["swh-search", "swh-indexer-storage"])
 def test_api_origin_metadata_search(api_client, mocker, backend):
 
-    mock_config = mocker.patch("swh.web.common.archive.config")
+    mock_config = mocker.patch("swh.web.utils.archive.config")
     mock_config.get_config.return_value = {
         "search_config": {"metadata_backend": backend}
     }
@@ -696,7 +701,7 @@ def test_api_origin_metadata_search(api_client, mocker, backend):
             {
                 "url": origin_url,
                 "metadata": {
-                    "from_revision": ORIGIN_MASTER_REVISION[origin_url],
+                    "from_directory": ORIGIN_MASTER_DIRECTORY[origin_url],
                     "tool": {
                         "name": INDEXER_TOOL["tool_name"],
                         "version": INDEXER_TOOL["tool_version"],
@@ -724,18 +729,18 @@ def test_api_origin_metadata_search(api_client, mocker, backend):
 
 
 def test_api_origin_metadata_search_limit(api_client, mocker):
-    mock_idx_storage = mocker.patch("swh.web.common.archive.idx_storage")
+    mock_idx_storage = mocker.patch("swh.web.utils.archive.idx_storage")
     oimsft = mock_idx_storage.origin_intrinsic_metadata_search_fulltext
 
     oimsft.side_effect = lambda conjunction, limit: [
         OriginIntrinsicMetadataRow(
             id=origin_url,
-            from_revision=hash_to_bytes(master_rev),
+            from_directory=hash_to_bytes(directory),
             indexer_configuration_id=INDEXER_TOOL["id"],
             metadata={ORIGIN_METADATA_KEY: ORIGIN_METADATA_VALUE},
             mappings=[],
         )
-        for origin_url, master_rev in ORIGIN_MASTER_REVISION.items()
+        for origin_url, directory in ORIGIN_MASTER_DIRECTORY.items()
     ]
 
     url = reverse(
@@ -774,7 +779,7 @@ def test_api_origin_intrinsic_metadata(api_client, origin):
 
 
 def test_api_origin_metadata_search_invalid(api_client, mocker):
-    mock_idx_storage = mocker.patch("swh.web.common.archive.idx_storage")
+    mock_idx_storage = mocker.patch("swh.web.utils.archive.idx_storage")
     url = reverse("api-1-origin-metadata-search")
     check_api_get_responses(api_client, url, status_code=400)
     mock_idx_storage.assert_not_called()
@@ -783,7 +788,7 @@ def test_api_origin_metadata_search_invalid(api_client, mocker):
 @pytest.mark.parametrize("backend", ["swh-counters", "swh-storage"])
 def test_api_stat_counters(api_client, mocker, backend):
 
-    mock_config = mocker.patch("swh.web.common.archive.config")
+    mock_config = mocker.patch("swh.web.utils.archive.config")
     mock_config.get_config.return_value = {"counters_backend": backend}
 
     url = reverse("api-1-stat-counters")
@@ -836,3 +841,27 @@ def test_api_origin_search_empty_pattern_and_visit_type(api_client, archived_ori
         assert {o["url"] for o in rv.data} == {
             o["url"] for o in archived_origins if o["type"] == visit_type
         }
+
+
+@pytest.mark.parametrize(
+    "view_name, extra_args",
+    [
+        ("api-1-origin", {}),
+        ("api-1-origin-visits", {}),
+        ("api-1-origin-visit", {"visit_id": 1}),
+        ("api-1-origin-visit-latest", {}),
+        ("api-origin-intrinsic-metadata", {}),
+    ],
+)
+def test_api_origin_by_url_with_extra_trailing_slash(
+    api_client, origin, view_name, extra_args
+):
+    origin_url = origin["url"]
+    assert not origin_url.endswith("/")
+    origin_url = origin_url + "/"
+    url = reverse(view_name, url_args={"origin_url": origin_url, **extra_args})
+    rv = check_api_get_responses(api_client, url, status_code=404)
+    assert rv.data == {
+        "exception": "NotFoundExc",
+        "reason": f"Origin with url {origin_url} not found!",
+    }
