@@ -22,12 +22,12 @@ from swh.model.model import (
 from swh.model.swhids import ObjectType
 from swh.storage.utils import now
 from swh.web.browse.snapshot_context import process_snapshot_branches
-from swh.web.common.exc import NotFoundExc
-from swh.web.common.identifiers import gen_swhid
-from swh.web.common.utils import format_utc_iso_date, parse_iso8601_date_to_utc, reverse
 from swh.web.tests.django_asserts import assert_contains, assert_not_contains
+from swh.web.tests.helpers import check_html_get_response
 from swh.web.tests.strategies import new_origin, new_snapshot, visit_dates
-from swh.web.tests.utils import check_html_get_response
+from swh.web.utils import format_utc_iso_date, parse_iso8601_date_to_utc, reverse
+from swh.web.utils.exc import NotFoundExc
+from swh.web.utils.identifiers import gen_swhid
 
 
 def test_origin_visits_browse(client, archive_data, origin_with_multiple_visits):
@@ -35,7 +35,7 @@ def test_origin_visits_browse(client, archive_data, origin_with_multiple_visits)
     url = reverse("browse-origin-visits", query_params={"origin_url": origin_url})
 
     resp = check_html_get_response(
-        client, url, status_code=200, template_used="browse/origin-visits.html"
+        client, url, status_code=200, template_used="browse-origin-visits.html"
     )
 
     visits = archive_data.origin_visit_get(origin_url)
@@ -50,8 +50,13 @@ def test_origin_visits_browse(client, archive_data, origin_with_multiple_visits)
 
     _check_origin_link(resp, origin_url)
 
+    assert_contains(resp, "swh-take-new-snashot")
 
-def test_origin_root_directory_view(client, archive_data, swh_scheduler, origin):
+
+@pytest.mark.django_db
+def test_origin_root_directory_view(
+    client, staff_user, archive_data, swh_scheduler, origin
+):
     origin_visits = archive_data.origin_visit_get(origin["url"])
 
     visit = origin_visits[-1]
@@ -65,6 +70,7 @@ def test_origin_root_directory_view(client, archive_data, swh_scheduler, origin)
 
     _origin_directory_view_test_helper(
         client,
+        staff_user,
         archive_data,
         origin,
         visit,
@@ -72,11 +78,13 @@ def test_origin_root_directory_view(client, archive_data, swh_scheduler, origin)
         branches,
         releases,
         root_dir_sha1,
+        root_dir_sha1,
         dir_content,
     )
 
     _origin_directory_view_test_helper(
         client,
+        staff_user,
         archive_data,
         origin,
         visit,
@@ -84,12 +92,14 @@ def test_origin_root_directory_view(client, archive_data, swh_scheduler, origin)
         branches,
         releases,
         root_dir_sha1,
+        root_dir_sha1,
         dir_content,
         visit_id=visit["visit"],
     )
 
     _origin_directory_view_test_helper(
         client,
+        staff_user,
         archive_data,
         origin,
         visit,
@@ -97,12 +107,14 @@ def test_origin_root_directory_view(client, archive_data, swh_scheduler, origin)
         branches,
         releases,
         root_dir_sha1,
+        root_dir_sha1,
         dir_content,
         timestamp=visit["date"],
     )
 
     _origin_directory_view_test_helper(
         client,
+        staff_user,
         archive_data,
         origin,
         visit,
@@ -110,12 +122,14 @@ def test_origin_root_directory_view(client, archive_data, swh_scheduler, origin)
         branches,
         releases,
         root_dir_sha1,
+        root_dir_sha1,
         dir_content,
         snapshot_id=visit["snapshot"],
     )
 
     _origin_directory_view_test_helper(
         client,
+        staff_user,
         archive_data,
         origin,
         visit,
@@ -123,11 +137,13 @@ def test_origin_root_directory_view(client, archive_data, swh_scheduler, origin)
         branches,
         releases,
         root_dir_sha1,
+        root_dir_sha1,
         dir_content,
     )
 
     _origin_directory_view_test_helper(
         client,
+        staff_user,
         archive_data,
         origin,
         visit,
@@ -135,12 +151,14 @@ def test_origin_root_directory_view(client, archive_data, swh_scheduler, origin)
         branches,
         releases,
         root_dir_sha1,
+        root_dir_sha1,
         dir_content,
         visit_id=visit["visit"],
     )
 
     _origin_directory_view_test_helper(
         client,
+        staff_user,
         archive_data,
         origin,
         visit,
@@ -148,12 +166,14 @@ def test_origin_root_directory_view(client, archive_data, swh_scheduler, origin)
         branches,
         releases,
         root_dir_sha1,
+        root_dir_sha1,
         dir_content,
         timestamp=visit["date"],
     )
 
     _origin_directory_view_test_helper(
         client,
+        staff_user,
         archive_data,
         origin,
         visit,
@@ -161,12 +181,16 @@ def test_origin_root_directory_view(client, archive_data, swh_scheduler, origin)
         branches,
         releases,
         root_dir_sha1,
+        root_dir_sha1,
         dir_content,
         snapshot_id=visit["snapshot"],
     )
 
 
-def test_origin_sub_directory_view(client, archive_data, swh_scheduler, origin):
+@pytest.mark.django_db
+def test_origin_sub_directory_view(
+    client, staff_user, archive_data, swh_scheduler, origin
+):
     origin_visits = archive_data.origin_visit_get(origin["url"])
 
     visit = origin_visits[-1]
@@ -189,6 +213,7 @@ def test_origin_sub_directory_view(client, archive_data, swh_scheduler, origin):
 
     _origin_directory_view_test_helper(
         client,
+        staff_user,
         archive_data,
         origin,
         visit,
@@ -196,12 +221,14 @@ def test_origin_sub_directory_view(client, archive_data, swh_scheduler, origin):
         branches,
         releases,
         root_dir_sha1,
+        subdir["target"],
         subdir_content,
         path=subdir_path,
     )
 
     _origin_directory_view_test_helper(
         client,
+        staff_user,
         archive_data,
         origin,
         visit,
@@ -209,6 +236,7 @@ def test_origin_sub_directory_view(client, archive_data, swh_scheduler, origin):
         branches,
         releases,
         root_dir_sha1,
+        subdir["target"],
         subdir_content,
         path=subdir_path,
         visit_id=visit["visit"],
@@ -216,6 +244,7 @@ def test_origin_sub_directory_view(client, archive_data, swh_scheduler, origin):
 
     _origin_directory_view_test_helper(
         client,
+        staff_user,
         archive_data,
         origin,
         visit,
@@ -223,6 +252,7 @@ def test_origin_sub_directory_view(client, archive_data, swh_scheduler, origin):
         branches,
         releases,
         root_dir_sha1,
+        subdir["target"],
         subdir_content,
         path=subdir_path,
         timestamp=visit["date"],
@@ -230,6 +260,7 @@ def test_origin_sub_directory_view(client, archive_data, swh_scheduler, origin):
 
     _origin_directory_view_test_helper(
         client,
+        staff_user,
         archive_data,
         origin,
         visit,
@@ -237,6 +268,7 @@ def test_origin_sub_directory_view(client, archive_data, swh_scheduler, origin):
         branches,
         releases,
         root_dir_sha1,
+        subdir["target"],
         subdir_content,
         path=subdir_path,
         snapshot_id=visit["snapshot"],
@@ -244,6 +276,7 @@ def test_origin_sub_directory_view(client, archive_data, swh_scheduler, origin):
 
     _origin_directory_view_test_helper(
         client,
+        staff_user,
         archive_data,
         origin,
         visit,
@@ -251,12 +284,14 @@ def test_origin_sub_directory_view(client, archive_data, swh_scheduler, origin):
         branches,
         releases,
         root_dir_sha1,
+        subdir["target"],
         subdir_content,
         path=subdir_path,
     )
 
     _origin_directory_view_test_helper(
         client,
+        staff_user,
         archive_data,
         origin,
         visit,
@@ -264,6 +299,7 @@ def test_origin_sub_directory_view(client, archive_data, swh_scheduler, origin):
         branches,
         releases,
         root_dir_sha1,
+        subdir["target"],
         subdir_content,
         path=subdir_path,
         visit_id=visit["visit"],
@@ -271,6 +307,7 @@ def test_origin_sub_directory_view(client, archive_data, swh_scheduler, origin):
 
     _origin_directory_view_test_helper(
         client,
+        staff_user,
         archive_data,
         origin,
         visit,
@@ -278,6 +315,7 @@ def test_origin_sub_directory_view(client, archive_data, swh_scheduler, origin):
         branches,
         releases,
         root_dir_sha1,
+        subdir["target"],
         subdir_content,
         path=subdir_path,
         timestamp=visit["date"],
@@ -285,6 +323,7 @@ def test_origin_sub_directory_view(client, archive_data, swh_scheduler, origin):
 
     _origin_directory_view_test_helper(
         client,
+        staff_user,
         archive_data,
         origin,
         visit,
@@ -292,6 +331,7 @@ def test_origin_sub_directory_view(client, archive_data, swh_scheduler, origin):
         branches,
         releases,
         root_dir_sha1,
+        subdir["target"],
         subdir_content,
         path=subdir_path,
         snapshot_id=visit["snapshot"],
@@ -347,7 +387,7 @@ def test_origin_snapshot_null_branch(
     )
 
     check_html_get_response(
-        client, url, status_code=200, template_used="browse/directory.html"
+        client, url, status_code=200, template_used="browse-directory.html"
     )
 
 
@@ -414,10 +454,10 @@ def test_browse_visits_origin_not_found(client, new_origin):
 
 def test_browse_origin_directory_no_visit(client, mocker, origin):
     mock_get_origin_visits = mocker.patch(
-        "swh.web.common.origin_visits.get_origin_visits"
+        "swh.web.utils.origin_visits.get_origin_visits"
     )
     mock_get_origin_visits.return_value = []
-    mock_archive = mocker.patch("swh.web.common.origin_visits.archive")
+    mock_archive = mocker.patch("swh.web.utils.origin_visits.archive")
     mock_archive.lookup_origin_visit_latest.return_value = None
     url = reverse("browse-origin-directory", query_params={"origin_url": origin["url"]})
 
@@ -448,7 +488,7 @@ def test_browse_origin_directory_not_found(client, origin):
     )
 
     resp = check_html_get_response(
-        client, url, status_code=404, template_used="browse/directory.html"
+        client, url, status_code=404, template_used="browse-directory.html"
     )
     assert re.search("Directory.*not found", resp.content.decode("utf-8"))
 
@@ -494,7 +534,7 @@ def test_browse_origin_content_directory_empty_snapshot(
     )
 
     resp = check_html_get_response(
-        client, url, status_code=200, template_used=f"browse/{object_type}.html"
+        client, url, status_code=200, template_used=f"browse-{object_type}.html"
     )
     assert re.search("snapshot.*is empty", resp.content.decode("utf-8"))
 
@@ -523,7 +563,7 @@ def test_origin_empty_snapshot(client, archive_data, new_origin):
     )
 
     resp = check_html_get_response(
-        client, url, status_code=200, template_used="browse/directory.html"
+        client, url, status_code=200, template_used="browse-directory.html"
     )
     resp_content = resp.content.decode("utf-8")
     assert re.search("snapshot.*is empty", resp_content)
@@ -567,7 +607,7 @@ def test_origin_empty_snapshot_null_revision(client, archive_data, new_origin):
     )
 
     resp = check_html_get_response(
-        client, url, status_code=200, template_used="browse/directory.html"
+        client, url, status_code=200, template_used="browse-directory.html"
     )
     resp_content = resp.content.decode("utf-8")
     assert re.search("snapshot.*is empty", resp_content)
@@ -588,7 +628,7 @@ def test_origin_release_browse(client, archive_data, origin_with_releases):
     )
 
     resp = check_html_get_response(
-        client, url, status_code=200, template_used="browse/directory.html"
+        client, url, status_code=200, template_used="browse-directory.html"
     )
     assert_contains(resp, release_data["name"])
     assert_contains(resp, release["target"])
@@ -668,7 +708,7 @@ def test_origin_browse_directory_branch_with_non_resolvable_revision(
     )
 
     resp = check_html_get_response(
-        client, url, status_code=200, template_used="browse/directory.html"
+        client, url, status_code=200, template_used="browse-directory.html"
     )
     assert_contains(
         resp, f"Revision {unknown_revision } could not be found in the archive."
@@ -774,6 +814,7 @@ def test_origin_content_view_legacy_redirects(client, new_origin):
 
 def _origin_directory_view_test_helper(
     client,
+    staff_user,
     archive_data,
     origin_info,
     origin_visit,
@@ -781,6 +822,7 @@ def _origin_directory_view_test_helper(
     origin_branches,
     origin_releases,
     root_directory_sha1,
+    target_directory_sha1,
     directory_entries,
     visit_id=None,
     timestamp=None,
@@ -808,7 +850,7 @@ def _origin_directory_view_test_helper(
     url = reverse("browse-origin-directory", query_params=query_params)
 
     resp = check_html_get_response(
-        client, url, status_code=200, template_used="browse/directory.html"
+        client, url, status_code=200, template_used="browse-directory.html"
     )
     assert_contains(resp, '<td class="swh-directory">', count=len(dirs))
     assert_contains(resp, '<td class="swh-content">', count=len(files))
@@ -916,6 +958,43 @@ def _origin_directory_view_test_helper(
 
     assert_not_contains(resp, "swh-metadata-popover")
 
+    # Finally, check "Extrinsic metadata" dropdown:
+
+    origin_metadata_api_url = reverse(
+        "api-1-raw-extrinsic-metadata-origin-authorities",
+        url_args={"origin_url": origin_info["url"]},
+    )
+    directory_metadata_api_url = reverse(
+        "api-1-raw-extrinsic-metadata-swhid-authorities",
+        url_args={"target": f"swh:1:dir:{target_directory_sha1}"},
+    )
+    extrinsic_metadata_snippets = [
+        "Extrinsic metadata",
+        f'<a href="{origin_metadata_api_url}" class="dropdown-item" role="button">',
+        f'<a href="{directory_metadata_api_url}" class="dropdown-item" role="button">',
+    ]
+
+    client.logout()
+
+    resp = check_html_get_response(
+        client, url, status_code=200, template_used="browse-directory.html"
+    )
+    # None of the above should be present for logged-out users
+    for snippet in extrinsic_metadata_snippets:
+        assert_not_contains(resp, snippet)
+
+    client.force_login(staff_user)
+
+    resp = check_html_get_response(
+        client, url, status_code=200, template_used="browse-directory.html"
+    )
+
+    # But they should for staff users
+    for snippet in extrinsic_metadata_snippets:
+        assert_contains(resp, snippet)
+
+    client.logout()
+
 
 def _check_origin_link(resp, origin_url):
     browse_origin_url = reverse(
@@ -941,5 +1020,5 @@ def test_browse_pull_request_branch(
         query_params={"origin_url": origin_url, "branch": pr_branch},
     )
     check_html_get_response(
-        client, url, status_code=200, template_used="browse/directory.html"
+        client, url, status_code=200, template_used="browse-directory.html"
     )
