@@ -6,22 +6,26 @@
 from collections import defaultdict
 from datetime import timedelta
 import functools
+from importlib import import_module, reload
 import json
 import os
 import random
 import shutil
-from subprocess import PIPE, run
 import sys
 import time
 from typing import Any, Dict, List, Optional
 
 from _pytest.python import Function
-from hypothesis import HealthCheck, settings
+from hypothesis import HealthCheck
+from hypothesis import settings as hypothesis_settings
 import pytest
+from pytest_django.fixtures import SettingsWrapper
 
+from django.conf import settings
 from django.contrib.auth.models import User
 from django.core.cache import cache
-from django.test.utils import setup_databases  # type: ignore
+from django.test.utils import setup_databases
+from django.urls import clear_url_caches
 from rest_framework.test import APIClient, APIRequestFactory
 
 from swh.model.hashutil import (
@@ -40,13 +44,9 @@ from swh.web.auth.utils import (
     ADD_FORGE_MODERATOR_PERMISSION,
     MAILMAP_ADMIN_PERMISSION,
     MAILMAP_PERMISSION,
-    OIDC_SWH_WEB_CLIENT_ID,
 )
-from swh.web.common import converters
-from swh.web.common.origin_save import get_scheduler_load_task_types
-from swh.web.common.typing import OriginVisitInfo
-from swh.web.common.utils import browsers_supported_image_mimes
 from swh.web.config import get_config
+from swh.web.save_code_now.origin_save import get_scheduler_load_task_types
 from swh.web.tests.data import (
     get_tests_data,
     override_storages,
@@ -55,20 +55,16 @@ from swh.web.tests.data import (
     random_sha1_bytes,
     random_sha256,
 )
-from swh.web.tests.utils import create_django_permission
+from swh.web.tests.helpers import create_django_permission
+from swh.web.utils import browsers_supported_image_mimes, converters
+from swh.web.utils.typing import OriginVisitInfo
 
 os.environ["LC_ALL"] = "C.UTF-8"
 
-# Used to skip some tests
-ctags_json_missing = (
-    shutil.which("ctags") is None
-    or b"+json" not in run(["ctags", "--version"], stdout=PIPE).stdout
-)
-
 fossology_missing = shutil.which("nomossa") is None
 
 # Register some hypothesis profiles
-settings.register_profile("default", settings())
+hypothesis_settings.register_profile("default", hypothesis_settings())
 
 # we use getattr here to keep mypy happy regardless hypothesis version
 function_scoped_fixture_check = (
@@ -83,17 +79,17 @@ suppress_health_check = [
 ] + function_scoped_fixture_check
 
 
-settings.register_profile(
+hypothesis_settings.register_profile(
     "swh-web",
-    settings(
+    hypothesis_settings(
         deadline=None,
         suppress_health_check=suppress_health_check,
     ),
 )
 
-settings.register_profile(
+hypothesis_settings.register_profile(
     "swh-web-fast",
-    settings(
+    hypothesis_settings(
         deadline=None,
         max_examples=5,
         suppress_health_check=suppress_health_check,
@@ -109,7 +105,7 @@ def pytest_configure(config):
     # Use fast hypothesis profile by default if none has been
     # explicitly specified in pytest option
     if config.getoption("--hypothesis-profile") is None:
-        settings.load_profile("swh-web-fast")
+        hypothesis_settings.load_profile("swh-web-fast")
 
     # Small hack in order to be able to run the unit tests
     # without static assets generated by webpack.
@@ -132,12 +128,27 @@ def pytest_configure(config):
     if os.path.exists(webpack_stats):
         return
 
-    bundles_dir = os.path.join(test_dir, "../../../assets/src/bundles")
-    if not os.path.exists(bundles_dir):
-        # location of the bundles folder when running tests with tox
-        bundles_dir = os.path.join(data_dir, "assets/src/bundles")
+    django_apps_dir = os.path.join(test_dir, "../../../swh/web")
+    if not os.path.exists(django_apps_dir):
+        # location of the applications folder when running tests with tox
+        django_apps_dir = os.path.join(data_dir, "swh/web")
 
-    _, bundles, _ = next(os.walk(bundles_dir))
+    bundles = []
+    _, apps, _ = next(os.walk(django_apps_dir))
+    for app in apps:
+        app_assets_dir = os.path.join(django_apps_dir, app, "assets")
+        if os.path.exists(app_assets_dir):
+            if os.path.exists(os.path.join(app_assets_dir, "index.js")):
+                bundles.append(app)
+            else:
+                _, app_bundles, _ = next(os.walk(app_assets_dir))
+                for app_bundle in app_bundles:
+                    if os.path.exists(
+                        os.path.join(app_assets_dir, app_bundle, "index.js")
+                    ):
+                        bundles.append(app_bundle)
+
+    print(bundles)
 
     mock_webpack_stats = {
         "status": "done",
@@ -444,35 +455,6 @@ def content_utf8_detected_as_binary():
     return random.choice(_content_utf8_detected_as_binary())
 
 
-@pytest.fixture(scope="function")
-def contents_with_ctags():
-    """
-    Fixture returning contents ingested into the test archive.
-    Those contents are ctags compatible, that is running ctags on those lay results.
-    """
-    return {
-        "sha1s": [
-            "0ab37c02043ebff946c1937523f60aadd0844351",
-            "15554cf7608dde6bfefac7e3d525596343a85b6f",
-            "2ce837f1489bdfb8faf3ebcc7e72421b5bea83bd",
-            "30acd0b47fc25e159e27a980102ddb1c4bea0b95",
-            "4f81f05aaea3efb981f9d90144f746d6b682285b",
-            "5153aa4b6e4455a62525bc4de38ed0ff6e7dd682",
-            "59d08bafa6a749110dfb65ba43a61963d5a5bf9f",
-            "7568285b2d7f31ae483ae71617bd3db873deaa2c",
-            "7ed3ee8e94ac52ba983dd7690bdc9ab7618247b4",
-            "8ed7ef2e7ff9ed845e10259d08e4145f1b3b5b03",
-            "9b3557f1ab4111c8607a4f2ea3c1e53c6992916c",
-            "9c20da07ed14dc4fcd3ca2b055af99b2598d8bdd",
-            "c20ceebd6ec6f7a19b5c3aebc512a12fbdc9234b",
-            "e89e55a12def4cd54d5bff58378a3b5119878eb7",
-            "e8c0654fe2d75ecd7e0b01bee8a8fc60a130097e",
-            "eb6595e559a1d34a2b41e8d4835e0e4f98a5d2b5",
-        ],
-        "symbol_name": "ABS",
-    }
-
-
 @pytest.fixture(scope="function")
 def directory(tests_data):
     """Fixture returning a random directory ingested into the test archive."""
@@ -1030,7 +1012,6 @@ class _IndexerData:
         self.idx_storage = tests_data["idx_storage"]
         self.mimetype_indexer = tests_data["mimetype_indexer"]
         self.license_indexer = tests_data["license_indexer"]
-        self.ctags_indexer = tests_data["ctags_indexer"]
 
     def content_add_mimetype(self, cnt_id):
         self.mimetype_indexer.run([hash_to_bytes(cnt_id)])
@@ -1050,15 +1031,6 @@ class _IndexerData:
         for license in licenses:
             yield converters.from_swh(license.to_dict(), hashess={"id"})
 
-    def content_add_ctags(self, cnt_id):
-        self.ctags_indexer.run([hash_to_bytes(cnt_id)])
-
-    def content_get_ctags(self, cnt_id):
-        cnt_id_bytes = hash_to_bytes(cnt_id)
-        ctags = self.idx_storage.content_ctags_get([cnt_id_bytes])
-        for ctag in ctags:
-            yield converters.from_swh(ctag, hashess={"id"})
-
 
 @pytest.fixture
 def keycloak_oidc(keycloak_oidc, mocker):
@@ -1066,7 +1038,7 @@ def keycloak_oidc(keycloak_oidc, mocker):
 
     keycloak_oidc.server_url = keycloak_config["server_url"]
     keycloak_oidc.realm_name = keycloak_config["realm_name"]
-    keycloak_oidc.client_id = OIDC_SWH_WEB_CLIENT_ID
+    keycloak_oidc.client_id = settings.OIDC_SWH_WEB_CLIENT_ID
 
     keycloak_oidc_client = mocker.patch("swh.web.auth.views.keycloak_oidc_client")
     keycloak_oidc_client.return_value = keycloak_oidc
@@ -1103,8 +1075,10 @@ def subtest(request):
         nextitem = parent_test  # prevents pytest from tearing down module fixtures
 
         item.ihook.pytest_runtest_setup(item=item)
-        item.ihook.pytest_runtest_call(item=item)
-        item.ihook.pytest_runtest_teardown(item=item, nextitem=nextitem)
+        try:
+            item.ihook.pytest_runtest_call(item=item)
+        finally:
+            item.ihook.pytest_runtest_teardown(item=item, nextitem=nextitem)
 
     return inner
 
@@ -1246,3 +1220,42 @@ def mailmap_user():
     mailmap_user = User.objects.create_user(username="mailmap-user", password="")
     mailmap_user.user_permissions.add(create_django_permission(MAILMAP_PERMISSION))
     return mailmap_user
+
+
+def reload_urlconf():
+    from django.conf import settings
+
+    clear_url_caches()
+    # force reloading of all URLs as they depend on django settings
+    # and swh-web configuration
+    urlconfs = [settings.ROOT_URLCONF]
+    urlconfs += [f"{app}.urls" for app in settings.SWH_DJANGO_APPS]
+    for urlconf in urlconfs:
+        try:
+            if urlconf in sys.modules:
+                reload(sys.modules[urlconf])
+            else:
+                import_module(urlconf)
+        except ModuleNotFoundError:
+            pass
+
+
+class SwhSettingsWrapper(SettingsWrapper):
+    def __setattr__(self, attr: str, value) -> None:
+        super().__setattr__(attr, value)
+        reload_urlconf()
+
+    def finalize(self) -> None:
+        super().finalize()
+        reload_urlconf()
+
+
+@pytest.fixture
+def django_settings():
+    """Override pytest-django settings fixture in order to reload URLs
+    when modifying settings in test and after test execution as most of
+    them depend on installed django apps in swh-web.
+    """
+    settings = SwhSettingsWrapper()
+    yield settings
+    settings.finalize()
